@@ -448,9 +448,9 @@ class Contract(BaseContent):
 
         for hour in self.hour_spread.hours:
             if hour.startswith('odd'):
-                odd_weeks += self.hour_spread.hours[hour]
+                odd_weeks += float(self.hour_spread.hours[hour])
             else:
-                even_weeks += self.hour_spread.hours[hour]
+                even_weeks += float(self.hour_spread.hours[hour])
 
         if odd_weeks == even_weeks:
             return str(int(odd_weeks))
