@@ -42,5 +42,7 @@ class Letter(Contract):
                      in tool.listTemplates('letter')]
             return DisplayList(items)
 
+    def is_contract(self):
+        return False
 
 registerType(Letter, config.PROJECTNAME)
